@@ -9,9 +9,9 @@ test_that("Testing get_sims function", {
   sims = get_bootstrap_sims(m, 4, threads = 2, seed = 1)
 
   m1 = displ$new(sims[, 1])
-  expect_equal(estimate_xmin(m1)$gof, bs$bootstraps$gof[1], tol = 1e-3)
+  expect_equal(estimate_xmin(m1)$gof, bs$bootstraps$gof[1], tolerance = 1e-3)
   m1 = displ$new(sims[, 4])
-  expect_equal(estimate_xmin(m1)$gof, bs$bootstraps$gof[4], tol = 1e-3)
+  expect_equal(estimate_xmin(m1)$gof, bs$bootstraps$gof[4], tolerance = 1e-3)
 
   ## Standard bootstrap - expect difference
   sims = get_bootstrap_sims(m, 4, threads = 2, seed = 2)
@@ -25,9 +25,9 @@ test_that("Testing get_sims function", {
   sims = get_bootstrap_p_sims(m, no_of_sims = 4, threads = 2, seed = 1)
 
   m1 = displ$new(sims[, 1])
-  expect_equal(estimate_xmin(m1)$gof, bs$bootstraps$gof[1], tol = 1e-3)
+  expect_equal(estimate_xmin(m1)$gof, bs$bootstraps$gof[1], tolerance = 1e-3)
   m1 = displ$new(sims[, 4])
-  expect_equal(estimate_xmin(m1)$gof, bs$bootstraps$gof[4], tol = 1e-3)
+  expect_equal(estimate_xmin(m1)$gof, bs$bootstraps$gof[4], tolerance = 1e-3)
   ## Expect difference
   sims = get_bootstrap_p_sims(m, 4, threads = 2, seed = 2)
   m1 = displ$new(sims[, 1])
